<?php
// Require common utilities and functions required to run Nagios XI
require_once(dirname(__FILE__) . '/../includes/common.inc.php');
require_once(dirname(__FILE__) . '/../includes/configwizards.inc.php');
  
// Initialization stuff
pre_init();
init_session(); // Connect to databases, handle cookies/session, set page headers
  
// Grab GET or POST variables and check pre-reqs
grab_request_vars();
check_prereqs();
check_authentication();
  
// Start the page
do_page_start(array("page_title" => _('Your Recent / Top Wizards')), true);
?>

<!-- Print text to the screen -->
<!-- _() is a translation function, used to localize text by matching the passed in
string to a translation dictionary. -->

<div class="wiz-table">

        <?php
        // This is the section of code from monitoringwizard.php that makes the config wizard table
        // Potentially could modify to show the X most recently and / or most commonly used wizards
        // For most common, requires adding a RunsCompleted field to SQL table
        // For most recent, requires adding LastRun field to SQL table
        // Requires getting these values from the table first, then adding the top X / most recent X wizards to the page
        if (can_add_more_objects()) {

            global $db_tables;
            
            // base url has to be absolute else href appends to the current url (which will lead nowhere
            // unless the user is currently in /nagiosxi/config/monitoringwizard.php)
            $base_url = "/nagiosxi/config/monitoringwizard.php?update=1&nextstep=2&nsp=" . get_nagios_session_protector_id() . "&wizard=";

            // SQL query to sort the table by runs_completed (descending)
            $user_id = $_SESSION["user_id"];
            $sql = "SELECT wizard_name FROM " . $db_tables[DB_NAGIOSXI]["wizard_history"];
            $sql .= " WHERE runs_completed > 0 AND user_id = '$user_id'";
            $sql .= " ORDER BY runs_completed DESC";

            // Get the table returned from the SQL query
            $ret_val = exec_sql_query(DB_NAGIOSXI, $sql);
            $rows = $ret_val->GetRows();
            $history_length = sizeof($rows); // The number of wizards in the history table

            // Check if the user has used any wizards first
            if ($history_length != 0) {

            ?>
            <h1 class="wiz-header">
            <?php echo _('Your Top Wizards'); ?>
            </h1>
            <?php display_message($error, false, $msg); ?>
            <p><?php echo _('Below are your most popular wizards. Select the appropriate wizard to get started.'); ?></p>
            <?php

            // Get the top 8 wizards by runs_completed
            // Have to also check if there even are 8 wizards
                for ($x = 0; $x < 8; $x++) {
                    // In case there aren't enough wizards in history
                    if ($x == $history_length) {
                        break;
                    }
                    
                    $cw = $configwizards[$rows[$x]['wizard_name']];
                    
                    $wizard_url = $base_url . urlencode($cw[CONFIGWIZARD_NAME]);
                    $img = $cw[CONFIGWIZARD_PREVIEWIMAGE];
                    ?><div class="wiz-padbox<?php echo $classes; ?>">
                        <a href="<?php echo $wizard_url; ?>" class="wiz-padbox-inner">
                            <div class="wiz-box">
                                <?php if (!empty($img)) { ?><img src="<?php echo get_object_icon_url($img); ?>"><?php } ?>
                                <div class="wiz-box-text">
                                    <h5><?php echo $cw[CONFIGWIZARD_DISPLAYTITLE]; ?></h5>
                                    <p><?php echo $cw[CONFIGWIZARD_DESCRIPTION]; ?></p>
                                </div>
                                <div class="clear"></div>
                            </div>
                        </a>
                    </div><?php
                }

                ?>
                <h1 class="wiz-header">
                <?php echo _('Your Most Recently Used Wizards'); ?>
                </h1>
                <?php display_message($error, false, $msg); ?>
                <p><?php echo _('Below are your most recently used wizards. Select the appropriate wizard to get started.'); ?></p>
                <?php

                // SQL query to sort the table by last_run (descending)
                $sql = "SELECT wizard_name FROM " . $db_tables[DB_NAGIOSXI]["wizard_history"];
                $sql .= " WHERE runs_completed > 0 AND user_id = '$user_id'";
                $sql .= " ORDER BY last_run DESC";

                // Get the table returned from the SQL query
                $ret_val1 = exec_sql_query(DB_NAGIOSXI, $sql);
                $rows1 = $ret_val1->GetRows();
                
                // Get the top 8 wizards by last_run
                // Have to also check if there even are 8 wizards
                // Repetitive, should abstract this loop
                for ($x = 0; $x < 8; $x++) {
                    // In case there aren't enough wizards in history
                    if ($x == $history_length) {
                        break;
                    }

                    $cw = $configwizards[$rows1[$x]['wizard_name']];
                    $wizard_url = $base_url . urlencode($cw[CONFIGWIZARD_NAME]);
                    $img = $cw[CONFIGWIZARD_PREVIEWIMAGE];
                    ?><div class="wiz-padbox<?php echo $classes; ?>">
                        <a href="<?php echo $wizard_url; ?>" class="wiz-padbox-inner">
                            <div class="wiz-box">
                                <?php if (!empty($img)) { ?><img src="<?php echo get_object_icon_url($img); ?>"><?php } ?>
                                <div class="wiz-box-text">
                                    <h5><?php echo $cw[CONFIGWIZARD_DISPLAYTITLE]; ?></h5>
                                    <p><?php echo $cw[CONFIGWIZARD_DESCRIPTION]; ?></p>
                                </div>
                                <div class="clear"></div>
                            </div>
                        </a>
                    </div><?php
                }
                
            // If the user hasn't used any wizards, display a message telling them such
            } else {
                ?> 
                <h1 class="wiz-header">
                <?php echo _('Your Top Wizards'); ?>
                </h1>
                <?php display_message($error, false, $msg); ?>
                <p><?php echo _('You have not used any wizards.'); ?></p>

                <h1 class="wiz-header">
                <?php echo _('Your Most Recently Used Wizards'); ?>
                </h1>
                <?php display_message($error, false, $msg); ?>
                <p><?php echo _('You have not used any wizards.'); ?></p>
            <?php
            }
            // Can't configure any more objects because it'd be over the limit!
        } else {
            $license = get_v2_license();
        ?>   
            
        <div style="margin: 0 10px;" class="alert alert-warning alert-max-checks">
            <h2><?php echo _('Max Checks Reached'); ?></h2>
            <?php if ($license['type'] == 'cloud') { ?>
            <p><?php echo _('You are using') . ' <b>' . get_active_checks_count() . '</b> ' . _('of') . ' <b>' . $license['restriction_max'] . '</b> ' . _('the') . ' ' . $license['restriction'] . ' ' . _('available for this instance.'); ?><br><?php echo _('To add more, either upgrade the instance via your'); ?> <a href="https://nagios.cloud/login" target="_new"><?php echo _('cloud account'); ?></a> <i class="fa fa-external-link"></i> <?php echo _('or remove old') . ' ' . $license['restriction'] . ' ' . _('you no longer need.'); ?></p>
            <?php } else { ?>
            <p><?php echo _('You are using') . ' <b>' . get_active_host_license_count() . '</b> ' . _('of') . ' <b>' . $license['restriction_max'] . '</b> ' . _('the') . ' ' . $license['restriction'] . ' ' . _('available for this instance.'); ?><br><?php echo _('To add more, upgrade your license or remove old') . ' ' . $license['restriction'] . ' ' . _('you no longer need.'); ?></p>
            <?php } ?>
        </div>
    <?php } ?>
</div>
<!-- End the page -->
<?php do_page_end(true); ?>